#
# spec file for package rpi-imager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rpi-imager
Version:        1.9.0
Release:        1.2
Summary:        Raspberry Pi Imaging Utility
License:        Apache-2.0
Group:          Hardware/Other
URL:            https://github.com/raspberrypi/rpi-imager
Source:         https://github.com/raspberrypi/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         0000-remove-vendoring.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libarchive-devel
BuildRequires:  libcurl-devel
BuildRequires:  libgnutls-devel
BuildRequires:  lzma-devel
BuildRequires:  qt6-concurrent-devel
BuildRequires:  qt6-core-devel
BuildRequires:  qt6-dbus-devel
BuildRequires:  qt6-linguist-devel
BuildRequires:  qt6-quick-devel
BuildRequires:  qt6-svg-devel
BuildRequires:  qt6-widgets-devel
BuildRequires:  util-linux-systemd

Requires:       dosfstools
Requires:       udisks2
Requires:       util-linux-systemd

Recommends:     polkit-gnome

ExcludeArch:    s390x

%description
Raspberry Pi Imager is the quick and easy way to install Raspberry Pi OS and
other operating systems to a microSD card, ready to use with your Raspberry
Pi. Watch our 45-second video to learn how to install an operating system
using Raspberry Pi Imager.

Download and install Raspberry Pi Imager to a computer with an SD card reader.
Put the SD card you'll use with your Raspberry Pi into the reader and run
Raspberry Pi Imager.

NOTE: Relies on polkit when run as regular user. It doesn't have to be
      polkit-gnome, but it has a low install base overhead.

%prep
%autosetup -p1

%build
pushd src
%cmake -DENABLE_CHECK_VERSION=OFF -DENABLE_TELEMETRY=OFF -DENABLE_VENDORING=OFF
%cmake_build
popd

%install
pushd src
%cmake_install
popd

%files
%doc README.md
%license license.txt
%{_bindir}/rpi-imager
%{_datadir}/applications/*
%{_datadir}/icons/*
%{_datadir}/metainfo/*

%changelog
* Sun Oct 27 2024 Mikhail Paulyshka <me@mixaill.net>
- adding 0000-remove-vendoring.patch
- update dependencies
- version 1.9.0
  * appstream metainfo: Fix appstream-builder generation by @joebonrichie in #792
  * Add a message when there are no storage devices. Fixes #798 by @jedahan in #801
  * Update Italian language by @bovirus in #802
  * imagewriter: Use QCoreApplication::translate by @tdewey-rpi in #805
  * Update Italian language by @bovirus in #806
  * Exposing 'DRIVELIST_FILTER_SYSTEM_DRIVES' as a cmake variable by @MrSmoer in #816
  * OS Customisation: Validate usernames by @tdewey-rpi in #819
  * Update issue creation templates by @tdewey-rpi in #823
  * Update French translation by @martignoni in #833
  * cli: Add disable-eject by @tdewey-rpi in #860
  * Corrected the spelling for Kyiv by @diminDDL in #871
  * Fix timeout on systems with large numbers of loops by @waveform80 in #872
  * localectl doesn't work on modern Debian/Ubuntu by @waveform80 in #867
  * Update zh-CN (Simplified Chinese) translation by @ykla in #879
  * BCM2712d0 support by @tdewey-rpi in #884
  * Fix GPT signature test by @jadonk in #895
  * Linux/OSX: Fix reversed fsync check by @ali1234 in #903
  * v1.9.0: Roll-up by @tdewey-rpi in #920
* Sun Apr  7 2024 Christian Boltz <suse-beta@cboltz.de>
- rpi-imager only supports little-endian architectures, stop trying
  to build for (big-endian) s390x
* Tue Feb 27 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding "Recommends: polkit-gnome" along with a NOTE in the description
  since using the GUI as a non-root user will throw an error on the
  destination device.
* Tue Feb 27 2024 Scott Bradnick <scott.bradnick@suse.com>
- version 1.8.5
  * Retry on HTTP/2 errors.
  * Linux: Fix display of application name and icon on GNOME desktop environment.
  * Disable Link Time Optimization as precaution against hard to trace bugs.
- version 1.8.4
  * OS customisation: Fixed first character being dropped when replacing existing password
  * OS customisation: Impose character limits on usernames & hostnames
  * i18n: Added Polish translation
  * i18n: Updated Catalan, Japanese translations
  * cli: Fixed local file passing via --repo
* Wed Nov 29 2023 Mikhail Paulyshka <me@mixaill.net>
- add lzma-devel as build dependency
- version 1.8.3
  * Home: Device filtering reworked to download OS list eagerly
  * OS List: Fixed 'Recommended' tag annotation
  * i18n: Added zh-TW Traditional Chinese translation
  * i18n: Updated Korean, German, Ukranian, translations
  * build: Linux: Fix libdrm dependency requirement on non-embedded build.
  * Common: Disable QML caching entirely
  * OS customisation: Allow use if only cloudinit payload available
  * OS customisation: Allow empty PSK for 'Open' WiFi networks.
  * OS List: Use ImageList v4 URL
- version 1.8.1
  * Advanced options: Rename to OS customization
  * OS customization: change to tabbed UI
  * OS customization: make SSH public key field a textarea
  * OS customization: add convenience button to run ssh-keygen
  * OS customization: Enforce choice as part of write flow
  * OS customization: Fixes for state consistency across UI
  * Home: Add mechanism for selecting Raspberry Pi device
  * Shared: Multiple keyboard focus fixes
* Sun May 28 2023 Axel Braun <axel.braun@gmx.de>
- version 1.7.5
  * 567.patch removed (included in src)
  * various fixes for Windows
  * No changes from v1.7.4.1 for Linux and Mac other than version number
  version 1.7.4.1
  * Advanced settings: fix creating files on FAT partition that are an exact multiple of cluster size.
  * Advanced settings: allow end-of-directory marker to be missing in FAT32 root directory (fixes customizing Homebridge image)
  * Do you want to apply saved settings window: offer 'no' option, without clearing settings.
  * Linux: eject storage properly through udisks2.
  * Add Russian translation
* Thu Apr  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 567.patch: Fix build using gcc13.
* Wed Mar  8 2023 Axel Braun <axel.braun@gmx.de>
- version 1.7.4
  * Advanced settings: fix escaping single quotes ( ' ) in WLAN password
  * Windows only: when auto-detecting the WLAN password used by the computer running Imager, it now processes passwords that contain < > ' " & correctly.
  * Advanced settings: default to using username of logged-in user instead of 'pi'
  * Now uses a different method to edit files on the FAT partition to apply advanced settings. Imager now understands the FAT16/FAT32 file system format and can edit files by itself using the raw disk device, without having to rely on the operating system to mount the partition first.
  * French translation update
* Mon Oct 17 2022 Axel Braun <axel.braun@gmx.de>
- rpi-imager (1.7.3)
  * Linux: use GnuTLS instead of OpenSSL for computing SHA256
  * Fix persistenting public key authentication setting
  * Linux: prefill wlan PSK if Linux distro uses NetworkManager
  * Add digital signage icon
  * Fix ""Cannot send events to objects owned by a different thread" warning
  * Update Slovan/Korean language files
  * Allow selecting file names without extension
  * Add possibility to outsource handling of custom settings to script at
    /usr/lib/raspberrypi-sys-mods/imager_custom
  * Advanced settings: disallow invalid characters in hostname field
* Thu Apr 14 2022 Axel Braun <axel.braun@gmx.de>
- fix for new autoconf
* Tue Mar 29 2022 Axel Braun <axel.braun@gmx.de>
- version 1.7.2
- Advanced options: remove overscan option
- Advanced options: remove first run wizard suppression option
- gz/xz/zstd custom images: pad if image size is not dividable by 512 byte
- Store saved wifi password hashed
- Make buttons blue on focus, to ease keyboard navigation
- Add Japan, Korean translations
- rpi-imager-noupdates.diff removed (included in current version)
* Mon Feb 14 2022 Ludwig Nussel <lnussel@suse.de>
- new version 1.7.1
- disable telemetry and auto updates (rpi-imager-noupdates.diff)
* Thu Sep  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop rpi-imager.yaml as it is not used in spec file
- Fix Source URL
* Sun Aug  8 2021 Axel Braun <axel.braun@gmx.de>
- Categories and Generic name added to desktop file
* Wed Jul 28 2021 Axel Braun <axel.braun@gmx.de>
- version 1.6.2
  * specfile cleaned up
  * switch to cmake
  * desktop file fixed
  * desktop-file install
* Sun Apr 18 2021 eymeric dechelette <hatchchien@protonmail.com>
-first packaging
-see changelog at https://github.com/raspberrypi/rpi-imager/releases
